@@ -1,9 +1,11 @@
-# $Id: Persistence.pm 18 2008-11-07 18:11:57Z rcaputo $
-
 =head1 NAME
 
 Lexical::Persistence - Persistent lexical variable values for arbitrary calls.
 
+=head1 VERSION
+
+version 1.022
+
 =head1 SYNOPSIS
 
 	#!/usr/bin/perl
@@ -37,7 +39,7 @@ nearly every aspect of Lexical::Persistence's behavior.
 
 Lexical::Persistence lets your code access persistent data through
 lexical variables.  This example prints "some value" because the value
-of $x perists in the $lp object between setter() and getter().
+of $x persists in the $lp object between setter() and getter().
 
 	use Lexical::Persistence;
 
@@ -222,7 +224,7 @@ package Lexical::Persistence;
 use warnings;
 use strict;
 
-our $VERSION = '0.98';
+our $VERSION = '1.020';
 
 use Devel::LexAlias qw(lexalias);
 use PadWalker qw(peek_sub);
@@ -599,24 +601,29 @@ sub pop_arg_context {
 	$self->set_context( arg => $old_context );
 }
 
-=head1 BUGS
-
-Read them at
-http://rt.cpan.org/Public/Dist/Display.html?Name=lexical-persistence
-
-Report them at
-http://rt.cpan.org/Public/Bug/Report.html?Queue=lexical-persistence
-
 =head1 SEE ALSO
 
 L<POE::Stage>, L<Devel::LexAlias>, L<PadWalker>,
 L<Catalyst::Controller::BindLex>.
 
+=head2 BUG TRACKER
+
+https://rt.cpan.org/Dist/Display.html?Status=Active&Queue=Lexical-Persistence
+
+=head2 REPOSITORY
+
+http://github.com/rcaputo/lexical-persistence
+http://gitorious.org/lexical-persistence
+
+=head2 OTHER RESOURCES
+
+http://search.cpan.org/dist/Lexical-Persistence/
+
 =head1 COPYRIGHT
 
-Lexical::Persistence in copyright 2006 by Rocco Caputo.  All rights
-reserved.  Lexical::Persistence is free software.  It is released
-under the same terms as Perl itself.
+Lexical::Persistence in copyright 2006-2013 by Rocco Caputo.  All
+rights reserved.  Lexical::Persistence is free software.  It is
+released under the same terms as Perl itself.
 
 =head1 ACKNOWLEDGEMENTS
 
